BadgePosition class

The BadgePosition class represents position of badge on icon Has predefined positions for every angle

Constructors

BadgePosition({double? top, double? right, double? bottom, double? left})
const
BadgePosition.bottomLeft()
factory
BadgePosition.bottomRight()
factory
BadgePosition.topLeft()
factory
BadgePosition.topRight()
factory

Properties

bottom → double?
final
hashCode → int
The hash code for this object.
no setterinherited
left → double?
final
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
top → double?
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited